@@ -57,12 +57,8 @@ def count(*args, **kwargs):
 
 
 @_contextmanager
-def span(name, trace_id=None, parent_id=None, **tags):
-    if trace_id is None:
-        child = active.start(name, **tags)
-    else:
-        span = active.target.span(trace_id=trace_id, parent_id=parent_id, name=name)
-        child = Telemeter(active.target, span, **tags)
+def span(name, dtags={}, trace_id=None, parent_id=None, **kwtags):
+    child = active.start(name, dtags, trace_id, parent_id, **kwtags)
     _push(child)
 
     try:
